import { Ref, ComponentOptionsMixin, DefineComponent } from 'vue';
import twmApp from './types/App';
import twmBadge from './types/Badge';
import twmBlock from './types/Block';
import twmBlockFooter from './types/BlockFooter';
import twmBlockHeader from './types/BlockHeader';
import twmBlockTitle from './types/BlockTitle';
import twmButton from './types/Button';
import twmCard from './types/Card';
import twmCheckbox from './types/Checkbox';
import twmChip from './types/Chip';
import twmFab from './types/Fab';
import twmIcon from './types/Icon';
import twmLink from './types/Link';
import twmList from './types/List';
import twmListButton from './types/ListButton';
import twmListGroup from './types/ListGroup';
import twmListInput from './types/ListInput';
import twmListItem from './types/ListItem';
import twmMenuList from './types/MenuList';
import twmMenuListItem from './types/MenuListItem';
import twmNavbar from './types/Navbar';
import twmNavbarBackLink from './types/NavbarBackLink';
import twmPage from './types/Page';
import twmPanel from './types/Panel';
import twmPopover from './types/Popover';
import twmPopup from './types/Popup';
import twmPreloader from './types/Preloader';
import twmProgressbar from './types/Progressbar';
import twmRadio from './types/Radio';
import twmRange from './types/Range';
import twmSegmented from './types/Segmented';
import twmSegmentedButton from './types/SegmentedButton';
import twmSheet from './types/Sheet';
import twmStepper from './types/Stepper';
import twmTabbar from './types/Tabbar';
import twmTabbarLink from './types/TabbarLink';
import twmToast from './types/Toast';
import twmToggle from './types/Toggle';
import twmToolbar from './types/Toolbar';

// PROVIDER
declare const twmProvider: DefineComponent<
  {
    /**
     * App theme. If set to `'parent'` it will look for `ios` or `md` class on root `<html>` element, useful to use with parent framework like Framework7 or Ionic
     *
     * @default 'material'
     */
    theme: {
      type: StringConstructor;
      default: 'material';
    };
    /**
     * Include `dark:` variants (if dark theme is in use)
     *
     * @default false
     * */
    dark: {
      type: BooleanConstructor;
      default: false;
    };
    /**
     * Enables touch ripple effect in Material theme. Allows to globally disable touch ripple for all components
     *
     * @default true
     */
    touchRipple: {
      type: BooleanConstructor;
      default: true;
    };
  },
  () => JSX.Element,
  unknown,
  {},
  {},
  ComponentOptionsMixin,
  ComponentOptionsMixin,
  {}
>;

// HELPERS
declare const useTheme: () => Ref<'material' | 'ios'>;

export { twmApp, twmApp as App, twmBadge, twmBadge as Badge, twmBlock, twmBlock as Block, twmBlockFooter, twmBlockFooter as BlockFooter, twmBlockHeader, twmBlockHeader as BlockHeader, twmBlockTitle, twmBlockTitle as BlockTitle, twmButton, twmButton as Button, twmCard, twmCard as Card, twmCheckbox, twmCheckbox as Checkbox, twmChip, twmChip as Chip, twmFab, twmFab as Fab, twmIcon, twmIcon as Icon, twmLink, twmLink as Link, twmList, twmList as List, twmListButton, twmListButton as ListButton, twmListGroup, twmListGroup as ListGroup, twmListInput, twmListInput as ListInput, twmListItem, twmListItem as ListItem, twmMenuList, twmMenuList as MenuList, twmMenuListItem, twmMenuListItem as MenuListItem, twmNavbar, twmNavbar as Navbar, twmNavbarBackLink, twmNavbarBackLink as NavbarBackLink, twmPage, twmPage as Page, twmPanel, twmPanel as Panel, twmPopover, twmPopover as Popover, twmPopup, twmPopup as Popup, twmPreloader, twmPreloader as Preloader, twmProgressbar, twmProgressbar as Progressbar, twmRadio, twmRadio as Radio, twmRange, twmRange as Range, twmSegmented, twmSegmented as Segmented, twmSegmentedButton, twmSegmentedButton as SegmentedButton, twmSheet, twmSheet as Sheet, twmStepper, twmStepper as Stepper, twmTabbar, twmTabbar as Tabbar, twmTabbarLink, twmTabbarLink as TabbarLink, twmToast, twmToast as Toast, twmToggle, twmToggle as Toggle, twmToolbar, twmToolbar as Toolbar }
export { useTheme, twmProvider, twmProvider as Provider };
